QueryEngine

Struct QueryEngine 

pub struct QueryEngine<'a> { /* private fields */ }
Query handle over a classified ontology taxonomy.

Implementations

Source

impl<'a> QueryEngine<'a>

pub fn new(ontology: &'a Ontology, taxonomy: &'a Taxonomy) -> Self

Create a query engine over ontology and its taxonomy.

pub fn direct_subclasses(&self, class: EntityId) -> Result<Vec<EntityId>>

Return direct subclasses of the given class in the reduced taxonomy.

pub fn direct_superclasses(&self, class: EntityId) -> Result<Vec<EntityId>>

Return direct superclasses of the given class in the reduced taxonomy.

pub fn is_subsumed(&self, sub: EntityId, sup: EntityId) -> Result<bool>

Whether sub is subsumed by sup in the taxonomy.

pub fn equivalent_classes( &self, class: EntityId, ) -> Result<Option<Vec<EntityId>>>

Return the equivalence cluster containing class, if any.

pub fn unsatisfiable_classes(&self) -> Vec<EntityId>

List classes inferred unsatisfiable (⊥).

pub fn lookup(&self, iri: &str) -> Option<EntityId>

Resolve an entity IRI to its id.